@@ -8,14 +8,15 @@ from transformers import PreTrainedTokenizerBase
 from evaluate import load as load_metric
 from lazy_load import lazy_func
 from easydict import EasyDict as edict
+from frozendict import frozendict as fdict
 import funcy as fc
 import evaluate
-from dataclasses import dataclass, field
+from dataclasses import dataclass
 import re
 from transformers.tokenization_utils_base import PreTrainedTokenizerBase
+from frozendict import frozendict
 
 load_dataset = lazy_func(datasets.load_dataset)
-_ = None
 
 def get_name(dataset):
     try:
@@ -58,20 +59,18 @@ class Classification(Task):
     task_type = "SequenceClassification"
     dataset: Dataset = None
     data_collator = DefaultDataCollator()
-    tokenizer_kwargs: _ = field(
-        default_factory=lambda: edict(
+    tokenizer_kwargs: ... = fdict(
             truncation=True, padding="max_length", max_length=256
         )
-    )
     s1: str = "sentence1"
     s2: str = "sentence2"
     y: str = "labels"
-    num_labels = None
+    num_labels: int = None
 
     def __post_init__(self):
         super().__post_init__()
-        target = self.dataset["train"].features[self.y]
         if not self.num_labels:
+            target = self.dataset["train"].features[self.y]
             self.num_labels = 1 if "float" in target.dtype else target.num_classes
 
     def preprocess_function(self, examples):
@@ -97,8 +96,8 @@ class Classification(Task):
 
 @dataclass
 class DataCollatorForMultipleChoice:
-    tokenizer: None
-    tokenizer_kwargs: None
+    tokenizer: ... =None
+    tokenizer_kwargs: ... =None
 
     def __call__(self, features):
         label_name = "label" if "label" in features[0].keys() else "labels"
@@ -125,14 +124,11 @@ class DataCollatorForMultipleChoice:
 @dataclass
 class MultipleChoice(Classification):
     task_type = "MultipleChoice"
-    dataset: Dataset = None
-    tokenizer_kwargs: _ = field(
-        default_factory=lambda: edict(padding="max_length", max_length=256)
-    )
+    tokenizer_kwargs: ... = fdict(padding="max_length", max_length=256)
 
-    num_labels = 2
-    data_collator: _ = DataCollatorForMultipleChoice()
-    choices: _ = field(default_factory=list)
+    num_labels:int = 2
+    data_collator:...= DataCollatorForMultipleChoice()
+    choices: ... = tuple()
     s1: str = "inputs"
         
     def __post_init__(self):
@@ -172,13 +168,13 @@ class TokenClassification(Task):
     task_type = "TokenClassification"
     dataset: Dataset = None
     metric = evaluate.load("seqeval")
-    tokenizer_kwargs: _ = field(
-        default_factory=lambda: edict(
+    tokenizer_kwargs: ... = fdict(
             truncation=True, padding="max_length", max_length=256
         )
-    )
+
     tokens: str = None
     y: str = None
+    num_labels: int = None
 
     @staticmethod
     def align_labels_with_tokens(labels, word_ids):
@@ -205,7 +201,8 @@ class TokenClassification(Task):
     def __post_init__(self):
         super().__post_init__()
         target = self.dataset["train"].features[self.y]
-        self.num_labels = 1 if "float" in target.dtype else target.feature.num_classes
+        if not self.num_labels:
+            self.num_labels = 1 if "float" in target.dtype else target.feature.num_classes
         self.label_names = [f"{i}" for i in range(self.num_labels)]
 
     def set_tokenizer(self, tokenizer):
